========
Contents
========

.. toctree::
   :maxdepth: 2

   readme
   usage
   telemetry object
   decorators
   adding telemetry
   telemetry mixin
   process_type
   telemetry counters
   telemetry aggregation
   storage class
   reference/index
   contributing
   authors
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
